import { Controller } from "@hotwired/stimulus"

function hide(elem, hide) {
  if (hide) {
    elem.classList.add("hidden");
  } else {
    elem.classList.remove("hidden");
  }
}

export default class extends Controller {
  static targets = ["candidates"];

  connect() {
    const uid = document.body.dataset.loggedinUid;
    const isCandidate = this.candidatesTarget.querySelector(`a.candidate[data-candidate-uid="${uid}"]`);
    const isShiftcoordinator = document.body.dataset.isShiftcoordinator;

    this.element.querySelectorAll('.only-loggedin').forEach(el => {
      hide(el, !uid);
    });
    this.element.querySelectorAll('.only-loggedout').forEach(el => {
      hide(el, uid);
    });
    this.element.querySelectorAll('.only-candidate').forEach(el => {
      hide(el, !isCandidate);
    });
    this.element.querySelectorAll('.only-no-candidate').forEach(el => {
      hide(el, isCandidate);
    });
    this.element.querySelectorAll('.only-shiftcoordinator').forEach(el => {
      hide(el, !isShiftcoordinator);
    });
  }

  verifyLanguages(event) {
    const languagesFrom = document.body.dataset.languagesFrom;
    const languageSession = this.element.dataset.language;
    if (!languagesFrom) {
      return;
    }
    if (!languagesFrom.split(',').includes(languageSession)) {
      const response = confirm("You are signing up for a talk with language \"" + languageSession + "\", which you claim not to understand!");
      if (response) {
        return;
      } else {
        event.preventDefault();
        event.stopImmediatePropagation(); // don't continue with further actions on the same element
      }
    }
  }

  submitWithPrompt(event) {
    event.preventDefault();

    const reason = prompt(event.target.dataset.prompt, event.target.dataset?.prefill);
    if (reason !== null && event.target.dataset?.submitempty || reason.trim() !== "") {
      const input = document.createElement("input");
      input.type = "hidden";
      input.name = "note";
      input.value = reason;
      const form = event.target.closest("form");
      form.appendChild(input);
      form.requestSubmit();
    }
  }
}
